@@ -20,12 +20,12 @@ class RecordOutputMgr;
 class ComplementFile : public ToolBase {
 
 public:
-    ComplementFile(ContextComplement *context);
-    virtual ~ComplementFile();
+  ComplementFile(ContextComplement *context);
+  virtual ~ComplementFile();
 	virtual bool init();
 	virtual bool findNext(RecordKeyVector &hits);
 	virtual void processHits(RecordOutputMgr *outputMgr, RecordKeyVector &hits);
-    virtual void checkCoordinatesAgainstChromLength(const Record *rec);
+  virtual void checkCoordinatesAgainstChromLength(const Record *rec);
 	virtual void cleanupHits(RecordKeyVector &hits);
 	virtual bool finalizeCalculations() {return true;}
 	virtual void giveFinalReport(RecordOutputMgr *outputMgr);
@@ -36,7 +36,8 @@ protected:
 	Bed3Interval _outRecord;
 	string _currChrom;
 	const NewGenomeFile *_genomeFile;
-	int _currStartPos;
+	CHRPOS _currStartPos;
+  bool _onlyChromsWithBedRecords;
 	RecordOutputMgr *_outputMgr;
 	const vector<string> &_chromList;
 	int _currPosInGenomeList;
@@ -45,8 +46,7 @@ protected:
 
 	void outPutLastRecordInPrevChrom();
 	bool fastForward(const string &newChrom);
-	void printRecord(int endPos);
-
+	void printRecord(CHRPOS endPos);
 };
 
 
