@@ -108,7 +108,7 @@ void BedGenomeCoverage::StartNewChrom(const string& newChrom) {
     if (_visitedChromosomes.find(newChrom) != _visitedChromosomes.end()) {
         cerr << "Input error: Chromosome "
              << _currChromName
-             << " found in non-sequential lines. This suggests that the input file is not sorted correctly." 
+             << " found in non-sequential lines. This suggests that the input file is not sorted correctly."
              << endl;
     }
     _visitedChromosomes.insert(newChrom);
@@ -121,9 +121,9 @@ void BedGenomeCoverage::StartNewChrom(const string& newChrom) {
     if (_currChromSize >= 0)
         _currChromCoverage.resize(_currChromSize);
     else {
-        cerr << "Input error: Chromosome " 
-             << _currChromName 
-             << " found in your input file but not in your genome file." 
+        cerr << "Input error: Chromosome "
+             << _currChromName
+             << " found in your input file but not in your genome file."
              << endl;
         exit(1);
     }
@@ -132,7 +132,7 @@ void BedGenomeCoverage::StartNewChrom(const string& newChrom) {
 
 void BedGenomeCoverage::AddCoverage(CHRPOS start, CHRPOS end) {
     // process the first line for this chromosome.
-    // make sure the coordinates fit within the chrom 
+    // make sure the coordinates fit within the chrom
     if (start < _currChromSize)
         _currChromCoverage[start].starts++;
     if (end >= 0 && end < _currChromSize)
@@ -165,16 +165,16 @@ void BedGenomeCoverage::CoverageBed() {
         if (_bed->_status == BED_VALID) {
             if (_filterByStrand == true) {
                 if (a.strand.empty()) {
-                    cerr << "Input error: Interval is missing a strand value on line " 
-                         << _bed->_lineNum 
+                    cerr << "Input error: Interval is missing a strand value on line "
+                         << _bed->_lineNum
                          << "." <<endl;
                     exit(1);
                 }
                 if ( ! (a.strand == "-" || a.strand == "+") ) {
-                    cerr << "Input error: Invalid strand value (" 
-                         << a.strand << ") on line " 
-                         << _bed->_lineNum 
-                         << "." 
+                    cerr << "Input error: Invalid strand value ("
+                         << a.strand << ") on line "
+                         << _bed->_lineNum
+                         << "."
                          << endl;
                     exit(1);
                 }
@@ -258,8 +258,8 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
     // open the BAM file
     BamReader reader;
     if (!reader.Open(bamFile)) {
-        cerr << "Failed to open BAM file " 
-             << bamFile 
+        cerr << "Failed to open BAM file "
+             << bamFile
              << endl;
         exit(1);
     }
@@ -378,16 +378,29 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
 void BedGenomeCoverage::ReportChromCoverage(const vector<DEPTH> &chromCov, const CHRPOS &chromSize, const string &chrom, chromHistMap &chromDepthHist) {
 
     if (_eachBase) {
+        streamsize prec;
+        std::ios_base::fmtflags fflags;
+        if(_scale == 1.0) {
+            prec = cout.precision(0);
+            fflags = cout.setf(std::ios_base::fixed);
+        }
         int depth = 0; // initialize the depth
         CHRPOS offset = (_eachBaseZeroBased)?0:1;
         for (CHRPOS pos = 0; pos < chromSize; pos++) {
 
             depth += chromCov[pos].starts;
             // report the depth for this position.
-            if (depth>0 || !_eachBaseZeroBased)
-                cout << chrom << "\t" << pos+offset << "\t" << depth * _scale << endl;
+            if (depth>0 || !_eachBaseZeroBased) {
+                cout << chrom << "\t" << pos+offset << "\t"
+                     << depth * _scale
+                     << endl;
+            }
             depth = depth - chromCov[pos].ends;
         }
+        if(_scale == 1.0) {
+            cout.precision(prec);
+            cout.setf(fflags);
+        }
     }
     else if (_bedGraph == true || _bedGraphAll == true) {
         ReportChromCoverageBedGraph(chromCov, chromSize, chrom);
@@ -469,11 +482,18 @@ void BedGenomeCoverage::ReportGenomeCoverage(chromHistMap &chromDepthHist) {
 }
 
 
+
 void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCov, const CHRPOS &chromSize, const string &chrom) {
 
     int depth = 0; // initialize the depth
     CHRPOS lastStart = -1;
     int lastDepth = -1;
+    streamsize prec;
+    std::ios_base::fmtflags fflags;
+    if(_scale == 1.0) {
+        prec = cout.precision(0);
+        fflags = cout.setf(std::ios_base::fixed);
+    }
 
     for (CHRPOS pos = 0; pos < chromSize; pos++) {
         depth += chromCov[pos].starts;
@@ -488,13 +508,13 @@ void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCo
                 if (lastDepth >= _max) {
                     lastDepth = _max;
                 }
-                cout << chrom 
-                     << "\t" 
-                     << lastStart 
-                     << "\t" 
-                     << pos 
-                     << "\t" 
-                     << lastDepth * _scale 
+                cout << chrom
+                     << "\t"
+                     << lastStart
+                     << "\t"
+                     << pos
+                     << "\t"
+                     << lastDepth * _scale
                      << endl;
             }
             //Set current position as the new interval start + depth
@@ -508,13 +528,17 @@ void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCo
     }
     //Print information about the last position
     if ( (lastDepth != -1) && (lastDepth > 0 || _bedGraphAll) ) {
-        cout << chrom 
-             << "\t" 
-             << lastStart 
-             << "\t" 
-             << chromSize 
-             << "\t" 
-             << lastDepth * _scale 
+        cout << chrom
+             << "\t"
+             << lastStart
+             << "\t"
+             << chromSize
+             << "\t"
+             << lastDepth * _scale
              << endl;
     }
+    if(_scale == 1.0) {
+        cout.precision(prec);
+        cout.setf(fflags);
+    }
 }
