@@ -174,10 +174,10 @@ void slop_help(void) {
 
     cerr << "Notes: " << endl;
     cerr << "\t(1)  Starts will be set to 0 if options would force it below 0." << endl;
-    cerr << "\t(2)  Ends will be set to the chromosome length if  requested slop would" << endl;
+    cerr << "\t(2)  Ends will be set to the chromosome length if requested slop would" << endl;
     cerr <<        "\tforce it above the max chrom length." << endl;
 
-    cerr << "\t(3)  The genome file should tab delimited and structured as follows:" << endl;
+    cerr << "\t(3)  The genome file should be tab delimited and structured as follows:" << endl;
     cerr << "\n\t<chromName><TAB><chromSize>" << endl << endl;
     cerr << "\tFor example, Human (hg19):" << endl;
     cerr << "\tchr1\t249250621" << endl;
@@ -185,8 +185,16 @@ void slop_help(void) {
     cerr << "\t..." << endl;
     cerr << "\tchr18_gl000207_random\t4262" << endl << endl;
 
+    cerr << "Tip 1. Use samtools faidx to create a genome file from a FASTA: " << endl;
+    cerr << "\tOne can the samtools faidx command to index a FASTA file." << endl;
+    cerr << "\tThe resulting .fai index is suitable as a genome file, " << endl;
+    cerr << "\tas bedtools will only look at the first two, relevant columns" << endl;
+    cerr << "\tof the .fai file." << endl << endl;
+    cerr << "\tFor example:" << endl;
+    cerr << "\tsamtools faidx GRCh38.fa" << endl;
+    cerr << "\tbedtools slop -b 10 -i my.bed -g GRCh38.fa.fai" << endl << endl;
 
-    cerr << "Tips: " << endl;
+    cerr << "Tip 2. Use UCSC Table Browser to create a genome file: " << endl;
     cerr << "\tOne can use the UCSC Genome Browser's MySQL database to extract" << endl;
     cerr << "\tchromosome sizes. For example, H. sapiens:" << endl << endl;
     cerr << "\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\" << endl;
