@@ -48,11 +48,11 @@ bool SpacingFile::findNext(RecordKeyVector &hits)
 			if (_currRec->getChrName() == _prevRec->getChrName())
 			{
 				// do _currRec and _prevRec overlap?
-				if (_currRec->sameChromIntersects(_prevRec, false, false, 1E-9, 1E-9, false, false))
+				if (_currRec->sameChromIntersects(_prevRec, false, false, 1E-9, 1E-9, false, false, false))
 					_distance.append("-1");
 				else
 				{
-					int distance = _currRec->getStartPos() - _prevRec->getEndPos();
+					CHRPOS distance = _currRec->getStartPos() - _prevRec->getEndPos();
 					ostringstream s;
 					s << distance;
 					_distance.append(s.str());
