@@ -6,6 +6,7 @@
  */
 
 #include "ContextBase.h"
+#include "Random.h"
 #include <unistd.h>
 #include <sys/types.h>
 #include <cctype>
@@ -29,6 +30,7 @@ ContextBase::ContextBase()
   _writeB(false),
   _leftJoin(false),
   _writeCount(false),
+  _writeCountsPerDatabase(false),
   _writeOverlap(false),
   _writeAllOverlap(false),
   _haveFractionA(false),
@@ -139,6 +141,7 @@ bool ContextBase::determineOutputType() {
 	int fileIdx = hasIntersectMethods() ? _queryFileIdx : 0;
 	if (_files[fileIdx]->getFileType() == FileRecordTypeChecker::BAM_FILE_TYPE) {
 		setOutputFileType(FileRecordTypeChecker::BAM_FILE_TYPE);
+		_isCram = _files[fileIdx]->isCram();
 		return true;
 	}
 
@@ -270,7 +273,7 @@ bool ContextBase::isValidState()
 		return false;
 	}
 	if (getObeySplits()) {
-		_splitBlockInfo = new BlockMgr(_overlapFractionA, _reciprocalFraction);
+		_splitBlockInfo = new BlockMgr(_overlapFractionA, _overlapFractionB, _reciprocalFraction);
 	}
 	if (hasColumnOpsMethods()) {
 
@@ -380,7 +383,7 @@ int ContextBase::getUnspecifiedSeed()
 {
 	// thanks to Rob Long for the tip.
 	_seed = (unsigned)time(0)+(unsigned)getpid();
-	srand(_seed);
+	rand_set_seed(_seed);
 	return _seed;
 }
 
@@ -479,7 +482,7 @@ bool ContextBase::handle_seed()
 	}
 	_hasConstantSeed = true;
 	_seed  = atoi(_argv[_i+1]);
-	srand(_seed);
+	rand_set_seed(_seed);
 	markUsed(_i - _skipFirstArgs);
 	_i++;
 	markUsed(_i - _skipFirstArgs);
@@ -647,7 +650,7 @@ FileRecordMgr *ContextBase::getNewFRM(const string &filename, int fileIdx) {
 bool ContextBase::parseIoBufSize(string bufStr)
 {
 	char lastChar = bufStr[bufStr.size()-1];
-	int multiplier = 1;
+	size_t multiplier = 1;
 	if (!isdigit(lastChar)) {
 		switch (lastChar) {
 		case 'K':
@@ -673,7 +676,7 @@ bool ContextBase::parseIoBufSize(string bufStr)
 		_errorMsg = "\n***** ERROR: argument passed to -iobuf is not numeric. *****";
 		return false;
 	}
-	_ioBufSize = str2chrPos(bufStr) * multiplier;
+	_ioBufSize = (size_t)str2chrPos(bufStr) * multiplier;
 	if (_ioBufSize < MIN_ALLOWED_BUF_SIZE) {
 		_errorMsg = "\n***** ERROR: specified buffer size is too small. *****";
 		return false;
