@@ -27,7 +27,8 @@ FileRecordMgr::FileRecordMgr(const string &filename)
   _genomeFile(NULL),
   _ioBufSize(0),
   _noEnforceCoordSort(false),
-  _isGroupBy(false)
+  _isGroupBy(false),
+  _isCram(false)
  {
 }
 
@@ -69,6 +70,10 @@ bool FileRecordMgr::open(bool inheader){
 		_fileType = FileRecordTypeChecker::SINGLE_LINE_DELIM_TEXT_FILE_TYPE;
 		_recordType = FileRecordTypeChecker::NO_POS_PLUS_RECORD_TYPE;
 	}
+
+	if(_fileType == FileRecordTypeChecker::BAM_FILE_TYPE)
+		_isCram = _bufStreamMgr->getTypeChecker().isCram();
+
 	if (_fileType == FileRecordTypeChecker::UNKNOWN_FILE_TYPE || _recordType == FileRecordTypeChecker::UNKNOWN_RECORD_TYPE) {
 		cerr << "Error: Unable to determine type for file " << _filename << endl;
 		delete _bufStreamMgr;
@@ -165,7 +170,7 @@ void FileRecordMgr::testInputSortOrder(Record *record)
 
 
 	const string &currChrom = record->getChrName();
-	int currStart = record->getStartPos();
+	CHRPOS currStart = record->getStartPos();
 	if (record->isZeroLength()) {
 		currStart++;
 	}
@@ -246,3 +251,10 @@ const BamTools::RefVector & FileRecordMgr::getBamReferences() {
 	}
 	return static_cast<BamFileReader *>(_fileReader)->getReferences();
 }
+refs_t* FileRecordMgr::getCramRefs() {
+	if (_fileType != FileRecordTypeChecker::BAM_FILE_TYPE) {
+		cerr << "Error: Attempted to get BAM references from file " << _filename << ", which is NOT a BAM file." << endl;
+		exit(1);
+	}
+	return static_cast<BamFileReader *>(_fileReader)->getCramRefs();
+}
