@@ -24,8 +24,7 @@ bool Bed6Interval::initFromFile(SingleLineDelimTextFileReader *fileReader)
 }
 
 inline void print_record(const string& chrom_name, CHRPOS start, CHRPOS end, const string& name, const string& score, const string& strand, string& buf) {
-	static char buffer[4096];
-	snprintf(buffer, sizeof(buffer), "%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS"\t%s\t%s\t%s", chrom_name.c_str(), start, end, name.c_str(), score.c_str(), strand.c_str());
+	const char* buffer = buffer_printf("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS"\t%s\t%s\t%s", chrom_name.c_str(), start, end, name.c_str(), score.c_str(), strand.c_str());
 	buf.append(buffer);
 }
 
