@@ -26,12 +26,14 @@ NewChromSweep::NewChromSweep(ContextIntersect *context)
      _wasInitialized(false),
      _currQueryRec(NULL),
      _runToQueryEnd(_context->getRunToQueryEnd()),
+     _runToDbEnd(false),
      _lexicoDisproven(false),
      _lexicoAssumed(false),
      _lexicoAssumedFileIdx(-1),
      _testLastQueryRec(false)
 {
 	_filePrevChrom.resize(_numFiles);
+	_runToDbEnd = context->shouldRunToDbEnd();
 }
 
 
@@ -249,6 +251,11 @@ bool NewChromSweep::next(RecordKeyVector &retList) {
     }
 
     if (!nextRecord(true)) { // query EOF hit
+		if (_runToDbEnd) {
+			for(int idx = 0; idx < _numDBs; idx ++) {
+				for(;nextRecord(false, idx););
+			}
+		}
         return false; 
     }
 
