@@ -13,6 +13,7 @@
 #define BEDFILE_H
 
 // "local" includes
+#include "BedtoolsTypes.h"
 #include "gzstream.h"
 #include "lineFileUtilities.h"
 #include "fileType.h"
@@ -37,7 +38,6 @@ using namespace std;
 //*************************************************
 // Data type tydedef
 //*************************************************
-typedef uint32_t CHRPOS;
 typedef uint16_t BINLEVEL;
 typedef uint32_t BIN;
 typedef uint16_t USHORT;
@@ -46,22 +46,15 @@ typedef uint32_t UINT;
 //*************************************************
 // Genome binning constants
 //*************************************************
-const BIN      _numBins   = 37450;
-const BINLEVEL _binLevels = 7;
+const BINLEVEL _binLevels = 8;
 
-// bins range in size from 16kb to 512Mb
-// Bin  0          spans 512Mbp,   # Level 1
-// Bins 1-8        span 64Mbp,     # Level 2
-// Bins 9-72       span 8Mbp,      # Level 3
-// Bins 73-584     span 1Mbp       # Level 4
-// Bins 585-4680   span 128Kbp     # Level 5
-// Bins 4681-37449 span 16Kbp      # Level 6
-const BIN _binOffsetsExtended[] = {32678+4096+512+64+8+1, 4096+512+64+8+1, 512+64+8+1, 64+8+1, 8+1, 1, 0};
-//const BIN _binOffsetsExtended[] = {4096+512+64+8+1, 4096+512+64+8+1, 512+64+8+1, 64+8+1, 8+1, 1, 0};
+const BIN _binOffsetsExtended[] = {262144+32678+4096+512+64+8+1, 32678+4096+512+64+8+1, 4096+512+64+8+1, 512+64+8+1, 64+8+1, 8+1, 1, 0};
 
 const USHORT _binFirstShift = 14;       /* How much to shift to get to finest bin. */
 const USHORT _binNextShift  = 3;        /* How much to shift to get to next larger bin. */
 
+const BIN _numBins = (1 << (_binNextShift * _binLevels)) / ((1 << _binNextShift) - 1);
+
 
 //*************************************************
 // Common data structures
@@ -169,7 +162,7 @@ public:
       weight(0.0)
     {}
     
-    int size() const {
+    CHRPOS size() const {
         return end-start;
     }
 
@@ -256,7 +249,7 @@ struct BEDCOVLIST {
     bool   zeroLength;
 
     // Additional fields specific to computing coverage
-    vector< map<unsigned int, DEPTH> > depthMapList;
+    vector< map<CHRPOS, DEPTH> > depthMapList;
     vector<unsigned int> counts;
     vector<CHRPOS> minOverlapStarts;
     
@@ -351,7 +344,7 @@ inline bool isInteger(const std::string& s) {
 // return the amount of overlap between two features.  Negative if none and the
 // number of negative bases is the distance between the two.
 inline
-int overlaps(CHRPOS aS, CHRPOS aE, CHRPOS bS, CHRPOS bE) {
+CHRPOS overlaps(CHRPOS aS, CHRPOS aE, CHRPOS bS, CHRPOS bE) {
     return min(aE, bE) - max(aS, bS);
 }
 
@@ -520,10 +513,10 @@ private:
     bool _firstLine;
     vector<string> _bedFields;
     unsigned int _numFields;
-    int _merged_start;
-    int _merged_end;
+    CHRPOS _merged_start;
+    CHRPOS _merged_end;
     string _merged_chrom;
-    int _prev_start;
+    CHRPOS _prev_start;
     string _prev_chrom;
     unsigned long _total_length;
     unsigned long _total_flattened_length;
@@ -596,8 +589,8 @@ private:
                     
                     // test to see if the file has true blocked BED12 records
                     if (_numFields == 12) {
-                        int cdsStart = atoi(fields[6].c_str());
-                        int cdsEnd   = atoi(fields[7].c_str());
+                        CHRPOS cdsStart = stoll(fields[6].c_str());
+                        CHRPOS cdsEnd   = stoll(fields[7].c_str());
                         int numExons = atoi(fields[9].c_str());
 
                         if (cdsStart > 0 && cdsEnd > 0&& numExons > 0 &&
@@ -652,9 +645,9 @@ private:
             }
         }
         else {
-            cerr << "It looks as though you have less than 3 columns at line: " 
+            cerr << "It looks as though you have less than 3 columns at line " 
                  << _lineNum 
-                 << ".  Are you sure your files are tab-delimited?" 
+                 << " in file " << bedFile << ".  Are you sure your files are tab-delimited?" 
                  << endl;
             exit(1);
         }
@@ -674,8 +667,9 @@ private:
         if (_numFields == this->bedType) {
             bed.fields = fields;
             bed.chrom = fields[0];
-            int i;
-            i = atoi(fields[1].c_str());
+
+            CHRPOS i;
+            i = stoll(fields[1].c_str());
             if (i<0) {
                  cerr << "Error: malformed BED entry at line " 
                       << _lineNum 
@@ -683,8 +677,8 @@ private:
                       << endl;
                  exit(1);
             }
-            bed.start = (CHRPOS)i;
-            i = atoi(fields[2].c_str());
+            bed.start = i;
+            i = stoll(fields[2].c_str());
             if (i<0) {
                 cerr << "Error: malformed BED entry at line " 
                      << _lineNum 
@@ -692,7 +686,7 @@ private:
                      << endl;
                 exit(1);
             }
-            bed.end = (CHRPOS)i;
+            bed.end = i;
             
             // handle starts == end (e.g., insertions in reference genome)
             if (bed.start == bed.end) {
@@ -778,7 +772,7 @@ private:
             bed.fields = fields;
             bed.chrom  = fields[0];
             // VCF is one-based
-            bed.start  = atoi(fields[1].c_str()) - 1;  
+            bed.start  = stoll(fields[1].c_str()) - 1;  
             // VCF 4.0 stores the size of the affected REF allele.
             bed.end    = bed.start + fields[3].size(); 
             bed.strand = "+";
@@ -851,9 +845,9 @@ private:
             if (this->bedType >= 8 && _isGff) {
                 bed.chrom = fields[0];
                 if (isInteger(fields[3]))
-                    bed.start  = atoi(fields[3].c_str());
+                    bed.start  = stoll(fields[3].c_str());
                 if (isInteger(fields[4]))
-                    bed.end  = atoi(fields[4].c_str());
+                    bed.end  = stoll(fields[4].c_str());
                 bed.name   = fields[2];
                 bed.score  = fields[5];
                 bed.strand = fields[6].c_str();
@@ -942,24 +936,24 @@ public:
         // BED
         if (_isGff == false && _isVcf == false) {
             if (this->bedType == 3) {
-                printf ("%s\t%d\t%d\t", bed.chrom.c_str(), start, end);
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t", bed.chrom.c_str(), start, end);
             }
             else if (this->bedType == 4) {
-                printf ("%s\t%d\t%d\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t",
                     bed.chrom.c_str(), start, end, bed.name.c_str());
             }
             else if (this->bedType == 5) {
-                printf ("%s\t%d\t%d\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str());
             }
             else if (this->bedType == 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str(), bed.strand.c_str());
             }
             else if (this->bedType > 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
                 
@@ -974,7 +968,7 @@ public:
         }
         // VCF
         else if (_isGff == false && _isVcf == true) {
-            printf ("%s\t%d\t", bed.chrom.c_str(), start+1);
+            printf ("%s\t%" PRId_CHRPOS "\t", bed.chrom.c_str(), start+1);
 
             vector<uint16_t>::const_iterator othIt  = bed.other_idxs.begin();
             vector<uint16_t>::const_iterator othEnd = bed.other_idxs.end();
@@ -986,14 +980,14 @@ public:
         else if (_isGff == true) {
             // "GFF-8"
             if (this->bedType == 8) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end, bed.score.c_str(), 
                     bed.strand.c_str(), bed.fields[bed.other_idxs[1]].c_str());
             }
             // "GFF-9"
             else if (this->bedType == 9) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\t", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1028,24 +1022,24 @@ public:
         //BED
         if (_isGff == false && _isVcf == false) {
             if (this->bedType == 3) {
-                fprintf(out,"%s\t%d\t%d\n", bed.chrom.c_str(), start, end);
+                fprintf(out,"%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\n", bed.chrom.c_str(), start, end);
             }
             else if (this->bedType == 4) {
-                fprintf(out,"%s\t%d\t%d\t%s\n", 
+                fprintf(out,"%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\n",
                     bed.chrom.c_str(), start, end, bed.name.c_str());
             }
             else if (this->bedType == 5) {
-                fprintf(out,"%s\t%d\t%d\t%s\t%s\n", 
+                fprintf(out,"%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\n",
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str());
             }
             else if (this->bedType == 6) {
-                fprintf(out,"%s\t%d\t%d\t%s\t%s\t%s\n", 
+                fprintf(out,"%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
             }
             else if (this->bedType > 6) {
-                fprintf(out,"%s\t%d\t%d\t%s\t%s\t%s", 
+                fprintf(out,"%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
 
@@ -1061,7 +1055,7 @@ public:
         }
         // VCF
         else if (_isGff == false && _isVcf == true) {
-            fprintf(out,"%s\t%d", bed.chrom.c_str(), start+1);
+            fprintf(out,"%s\t%" PRId_CHRPOS, bed.chrom.c_str(), start+1);
 
             vector<uint16_t>::const_iterator othIt  = bed.other_idxs.begin();
             vector<uint16_t>::const_iterator othEnd = bed.other_idxs.end();
@@ -1074,7 +1068,7 @@ public:
         else if (_isGff == true) {
             // "GFF-8"
             if (this->bedType == 8) {
-                fprintf (out,"%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\n", 
+                fprintf (out,"%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1082,7 +1076,7 @@ public:
             }
             // "GFF-9"
             else if (this->bedType == 9) {
-                fprintf (out,"%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\n", 
+                fprintf (out,"%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1118,24 +1112,24 @@ public:
         // BED
         if (_isGff == false && _isVcf == false) {
             if (this->bedType == 3) {
-                printf ("%s\t%d\t%d\t", bed.chrom.c_str(), start, end);
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t", bed.chrom.c_str(), start, end);
             }
             else if (this->bedType == 4) {
-                printf ("%s\t%d\t%d\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t",
                     bed.chrom.c_str(), start, end, bed.name.c_str());
             }
             else if (this->bedType == 5) {
-                printf ("%s\t%d\t%d\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str());
             }
             else if (this->bedType == 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
             }
             else if (this->bedType > 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
                 
@@ -1150,7 +1144,7 @@ public:
         }
         // VCF
         else if (_isGff == false && _isVcf == true) {
-            printf ("%s\t%d\t", bed.chrom.c_str(), bed.start+1);
+            printf ("%s\t%" PRId_CHRPOS "\t", bed.chrom.c_str(), bed.start+1);
             vector<uint16_t>::const_iterator othIt  = bed.other_idxs.begin();
             vector<uint16_t>::const_iterator othEnd = bed.other_idxs.end();
             for ( ; othIt != othEnd; ++othIt) {
@@ -1161,7 +1155,7 @@ public:
         else if (_isGff == true) {
             // "GFF-8"
             if (this->bedType == 8) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1169,7 +1163,7 @@ public:
             }
             // "GFF-9"
             else if (this->bedType == 9) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\t", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t%s\t",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1202,24 +1196,24 @@ public:
         // BED
         if (_isGff == false && _isVcf == false) {
             if (this->bedType == 3) {
-                printf ("%s\t%d\t%d\n", bed.chrom.c_str(), start, end);
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\n", bed.chrom.c_str(), start, end);
             }
             else if (this->bedType == 4) {
-                printf ("%s\t%d\t%d\t%s\n", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\n",
                     bed.chrom.c_str(), start, end, bed.name.c_str());
             }
             else if (this->bedType == 5) {
-                printf ("%s\t%d\t%d\t%s\t%s\n", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\n",
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str());
             }
             else if (this->bedType == 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\n", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
             }
             else if (this->bedType > 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s", 
+                printf ("%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s",
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
 
@@ -1235,7 +1229,7 @@ public:
         }
         // VCF
         else if (_isGff == false && _isVcf == true) {
-            printf ("%s\t%d", bed.chrom.c_str(), bed.start+1);
+            printf ("%s\t%" PRId_CHRPOS, bed.chrom.c_str(), bed.start+1);
             vector<uint16_t>::const_iterator othIt  = bed.other_idxs.begin();
             vector<uint16_t>::const_iterator othEnd = bed.other_idxs.end();
             for ( ; othIt != othEnd; ++othIt) {
@@ -1247,14 +1241,14 @@ public:
         else if (_isGff == true) {
             // "GFF-8"
             if (this->bedType == 8) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\n", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),                                          bed.fields[bed.other_idxs[1]].c_str());
             }
             // "GFF-9"
             else if (this->bedType == 9) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\n", 
+                printf ("%s\t%s\t%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS "\t%s\t%s\t%s\t%s\n",
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
