@@ -288,4 +288,11 @@ CRAM_REFERENCE=test_ref.fa $BT genomecov -ibam empty.cram > obs
 check obs exp
 rm obs exp
 
+python mk-deep.py > deep.sam
+echo -e "    genomecov.t18...\c"
+echo "c1	1	1000000" > exp
+$BT genomecov -d -ibam deep.sam | head -1 > obs
+check obs exp
+rm obs exp deep.sam
+
 [[ $FAILURES -eq 0 ]] || exit 1;
