@@ -1,18 +1,22 @@
+set -e;
 BT=${BT-../../bin/bedtools}
 
+FAILURES=0;
+
 check()
 {
 	if diff $1 $2; then
     	echo ok
 	else
-    	echo fail
+    	FAILURES=$(expr $FAILURES + 1);
+		echo fail
 	fi
 }
 
 ###########################################################
 #  Test defaults
 ############################################################
-echo "    map.t01...\c"
+echo -e "    map.t01...\c"
 echo \
 "chr1	0	100	30
 chr1	100	200	1
@@ -27,7 +31,7 @@ rm obs exp
 ###########################################################
 #  Test sum
 ############################################################
-echo "    map.t02...\c"
+echo -e "    map.t02...\c"
 echo \
 "chr1	0	100	30
 chr1	100	200	1
@@ -43,7 +47,7 @@ rm obs exp
 ###########################################################
 #  Test count
 ############################################################
-echo "    map.t03...\c"
+echo -e "    map.t03...\c"
 echo \
 "chr1	0	100	3
 chr1	100	200	1
@@ -59,7 +63,7 @@ rm obs exp
 ###########################################################
 #  Test mean
 ############################################################
-echo "    map.t04...\c"
+echo -e "    map.t04...\c"
 echo \
 "chr1	0	100	10
 chr1	100	200	1
@@ -74,7 +78,7 @@ rm obs exp
 ###########################################################
 #  Test max
 ############################################################
-echo "    map.t05...\c"
+echo -e "    map.t05...\c"
 echo \
 "chr1	0	100	15
 chr1	100	200	1
@@ -89,7 +93,7 @@ rm obs exp
 ###########################################################
 #  Test min
 ############################################################
-echo "    map.t06...\c"
+echo -e "    map.t06...\c"
 echo \
 "chr1	0	100	5
 chr1	100	200	1
@@ -104,7 +108,7 @@ rm obs exp
 ###########################################################
 #  Test mode
 ############################################################
-echo "    map.t07...\c"
+echo -e "    map.t07...\c"
 echo \
 "chr1	0	100	5
 chr1	100	200	1
@@ -119,7 +123,7 @@ rm obs exp
 ###########################################################
 #  Test anti-mode
 ############################################################
-echo "    map.t08...\c"
+echo -e "    map.t08...\c"
 echo \
 "chr1	0	100	10
 chr1	100	200	1
@@ -135,7 +139,7 @@ rm obs exp
 ###########################################################
 #  Test column extraction from BEDPLUS
 ############################################################
-echo "    map.t09...\c"
+echo -e "    map.t09...\c"
 echo \
 "chr1	0	100	1,2,3,4,5,-6
 chr1	100	200	7
@@ -150,7 +154,7 @@ rm obs exp
 ###########################################################
 #  Test min
 ############################################################
-echo "    map.t10...\c"
+echo -e "    map.t10...\c"
 echo \
 "chr1	0	100	-6
 chr1	100	200	7
@@ -165,7 +169,7 @@ rm obs exp
 ###########################################################
 #  Test absmin
 ############################################################
-echo "    map.t11...\c"
+echo -e "    map.t11...\c"
 echo \
 "chr1	0	100	1
 chr1	100	200	7
@@ -180,7 +184,7 @@ rm obs exp
 ###########################################################
 #  Test max
 ############################################################
-echo "    map.t12...\c"
+echo -e "    map.t12...\c"
 echo \
 "chr1	0	100	5
 chr1	100	200	7
@@ -195,7 +199,7 @@ rm obs exp
 ###########################################################
 #  Test absmax
 ############################################################
-echo "    map.t13...\c"
+echo -e "    map.t13...\c"
 echo \
 "chr1	0	100	6
 chr1	100	200	7
@@ -210,7 +214,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t14...\c"
+echo -e "    map.t14...\c"
 echo \
 "chr1	0	100	chr1,chr1,chr1,chr1,chr1
 chr1	100	200	chr1
@@ -225,7 +229,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t15...\c"
+echo -e "    map.t15...\c"
 echo \
 "chr1	0	100	hg19_ccdsGene,hg19_ccdsGene,hg19_ccdsGene,hg19_ccdsGene,hg19_ccdsGene
 chr1	100	200	hg19_ccdsGene
@@ -240,7 +244,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t16...\c"
+echo -e "    map.t16...\c"
 echo \
 "chr1	0	100	start_codon,CDS,exon,CDS,exon
 chr1	100	200	exon
@@ -255,7 +259,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t17...\c"
+echo -e "    map.t17...\c"
 echo \
 "chr1	0	100	1,2,8,9,40
 chr1	100	200	40
@@ -270,7 +274,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t18...\c"
+echo -e "    map.t18...\c"
 echo \
 "chr1	0	100	9,11,20,17,200
 chr1	100	200	200
@@ -285,7 +289,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t19...\c"
+echo -e "    map.t19...\c"
 echo \
 "chr1	0	100	0.000000,0.000000,0.000000,0.000000,0.000000
 chr1	100	200	0.000000
@@ -300,7 +304,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t20...\c"
+echo -e "    map.t20...\c"
 echo \
 "chr1	0	100	+,+,+,+,+
 chr1	100	200	+
@@ -315,7 +319,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t21...\c"
+echo -e "    map.t21...\c"
 echo \
 "chr1	0	100	.,0,.,2,.
 chr1	100	200	.
@@ -330,7 +334,7 @@ rm obs exp
 ###########################################################
 #  Test GFF column extraction
 ############################################################
-echo "    map.t22..\c"
+echo -e "    map.t22..\c"
 echo \
 "chr1	0	100	gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";,gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";,gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";,gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";,gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";
 chr1	100	200	gene_id \"CCDS30744.1\"; transcript_id \"CCDS30744.1\";
@@ -345,7 +349,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t23..\c"
+echo -e "    map.t23..\c"
 echo \
 "chr1	0	100	chr1,chr1,chr1
 chr1	100	200	chr1,chr1
@@ -360,7 +364,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t24..\c"
+echo -e "    map.t24..\c"
 echo \
 "chr1	0	100	10,15,20
 chr1	100	200	110,130
@@ -375,7 +379,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t25..\c"
+echo -e "    map.t25..\c"
 echo \
 "chr1	0	100	rs6054257,.,rs6040355
 chr1	100	200	.,microsat1
@@ -390,7 +394,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t26..\c"
+echo -e "    map.t26..\c"
 echo \
 "chr1	0	100	G,T,A
 chr1	100	200	T,GTC
@@ -405,7 +409,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t27..\c"
+echo -e "    map.t27..\c"
 echo \
 "chr1	0	100	A,A,G,T
 chr1	100	200	.,G,GTCT
@@ -420,7 +424,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t28..\c"
+echo -e "    map.t28..\c"
 echo \
 "chr1	0	100	29,3,67
 chr1	100	200	47,50
@@ -435,7 +439,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t29..\c"
+echo -e "    map.t29..\c"
 echo \
 "chr1	0	100	PASS,q10,PASS
 chr1	100	200	PASS,PASS
@@ -450,7 +454,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t30..\c"
+echo -e "    map.t30..\c"
 echo \
 "chr1	0	100	NS=3;DP=14;AF=0.5;DB;H2,NS=3;DP=11;AF=0.017,NS=2;DP=10;AF=0.333,0.667;AA=T;DB
 chr1	100	200	NS=3;DP=13;AA=T,NS=3;DP=9;AA=G
@@ -465,7 +469,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t31..\c"
+echo -e "    map.t31..\c"
 echo \
 "chr1	0	100	GT:GQ:DP:HQ,GT:GQ:DP:HQ,GT:GQ:DP:HQ
 chr1	100	200	GT:GQ:DP:HQ,GT:GQ:DP
@@ -480,7 +484,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t32..\c"
+echo -e "    map.t32..\c"
 echo \
 "chr1	0	100	0|0:48:1:51,51,0|0:49:3:58,50,1|2:21:6:23,27
 chr1	100	200	0|0:54:7:56,60,0/1:35:4
@@ -495,7 +499,7 @@ rm obs exp
 ###########################################################
 #  Test VCF column extraction
 ############################################################
-echo "    map.t33..\c"
+echo -e "    map.t33..\c"
 echo \
 "
 *****
@@ -507,7 +511,7 @@ rm obs exp
 ###########################################################
 #  Test -header
 ############################################################
-echo "    map.t33..\c"
+echo -e "    map.t33..\c"
 echo \
 "#header
 chr1	0	100	0|0:48:1:51,51,0|0:49:3:58,50,1|2:21:6:23,27
@@ -523,7 +527,7 @@ rm obs exp
 ###########################################################
 #  Test -null
 ############################################################
-echo "    map.t33..\c"
+echo -e "    map.t33..\c"
 echo \
 "chr1	0	100	0|0:48:1:51,51,0|0:49:3:58,50,1|2:21:6:23,27
 chr1	100	200	0|0:54:7:56,60,0/1:35:4
@@ -537,7 +541,7 @@ check obs exp
 ###########################################################
 #  Test -s
 ############################################################
-echo "    map.t34..\c"
+echo -e "    map.t34..\c"
 echo \
 "chr1	0	10	a1	10	-	.
 chr2	10	20	a7	2	+	.
@@ -548,7 +552,7 @@ check obs exp
 ###########################################################
 #  Test -S
 ############################################################
-echo "    map.t35..\c"
+echo -e "    map.t35..\c"
 echo \
 "chr1	0	10	a1	10	-	a1
 chr2	10	20	a7	2	+	.
@@ -559,7 +563,7 @@ check obs exp
 ###########################################################
 #  Test -f 0.1
 ############################################################
-echo "    map.t36..\c"
+echo -e "    map.t36..\c"
 echo \
 "chr1	0	10	a1	10	-	a1
 chr2	10	20	a7	2	+	.
@@ -570,7 +574,7 @@ check obs exp
 ###########################################################
 #  Test -f 0.7
 ############################################################
-echo "    map.t37..\c"
+echo -e "    map.t37..\c"
 echo \
 "chr1	0	10	a1	10	-	.
 chr2	10	20	a7	2	+	.
@@ -581,7 +585,7 @@ check obs exp
 ###########################################################
 #  Test -f 0.9
 ############################################################
-echo "    map.t38..\c"
+echo -e "    map.t38..\c"
 echo \
 "chr1	0	10	a1	10	-	.
 chr2	10	20	a7	2	+	.
@@ -592,7 +596,7 @@ check obs exp
 ###########################################################
 #  Test -g
 ############################################################
-echo "    map.t39..\c"
+echo -e "    map.t39..\c"
 echo \
 "chr1	10	20	chr1
 chr2	10	20	chr2
@@ -605,7 +609,7 @@ check obs exp
 ###########################################################
 #  Test -g
 ############################################################
-echo "    map.t40..\c"
+echo -e "    map.t40..\c"
 echo \
 "chr1	10	20	chr1
 chr2	10	20	chr2
@@ -618,7 +622,7 @@ check obs exp
 ###########################################################
 #  Test invalid column
 ############################################################
-echo "    map.t41..\c"
+echo -e "    map.t41..\c"
 echo \
 "
 *****
@@ -630,7 +634,7 @@ rm obs exp
 ###########################################################
 #  Test invalid column
 ############################################################
-echo "    map.t42..\c"
+echo -e "    map.t42..\c"
 echo \
 "
 *****
@@ -642,7 +646,7 @@ rm obs exp
 ###########################################################
 #  Test invalid column
 ############################################################
-echo "    map.t43..\c"
+echo -e "    map.t43..\c"
 echo \
 "
 *****
@@ -657,7 +661,7 @@ rm obs exp
 #  DEPRECATED
 #  Test that Bam database is not allowed
 ############################################################
-echo "    map.t44...\c"
+echo -e "    map.t44...\c"
 #echo -e "\n*****\n***** ERROR: BAM database file not currently supported for column operations." > exp
 #$BT map -a ivls.bed -b values.bam 2> obs
 #check obs exp
@@ -669,7 +673,7 @@ echo ok
 ###########################################################
 #  Test that -split option works correctly
 ############################################################
-echo "    map.t45...\c"
+echo -e "    map.t45...\c"
 echo "chr1	0	50	three_blocks_match	15	+	0	0	0	3	10,10,10,	0,20,40,	." > exp
 $BT map -o sum -a three_blocks_match.bed -b three_blocks_nomatch.bed -split > obs
 check obs exp
@@ -692,7 +696,7 @@ rm obs exp
 ###########################################################
 #  Test that error is given when ops outnumber columns
 ############################################################
-echo "    map.t46...\c"
+echo -e "    map.t46...\c"
 echo \
 "chr1	0	100	3	30
 chr1	100	200	1	1
@@ -709,7 +713,7 @@ rm obs exp
 #  Test that error is given when columns outnumber ops,
 # if there are two or more ops.
 ############################################################
-echo "    map.t47...\c"
+echo -e "    map.t47...\c"
 echo \
 "
 *****
@@ -723,7 +727,7 @@ rm obs exp
 #  Test that numeric ops for non-numeric columns are
 # allowed, but give a warning
 ############################################################
-echo "    map.t48...\c"
+echo -e "    map.t48...\c"
 echo \
 " ***** WARNING: Non numeric value chr1 in 1.
  ***** WARNING: Non numeric value chr1 in 1.
@@ -738,7 +742,7 @@ rm obs exp
 #  Test that multiple columns are allowed with a 
 # single operation
 ############################################################
-echo "    map.t49...\c"
+echo -e "    map.t49...\c"
 echo \
 "chr1	0	100	65	9
 chr1	100	200	1	7
@@ -755,7 +759,7 @@ rm obs exp
 #  Test that multiple columns are allowed with an
 #  equal number of ops that aren't all the same
 ############################################################
-echo "    map.t50...\c"
+echo -e "    map.t50...\c"
 echo \
 "chr1	0	100	13.5	65	9
 chr1	100	200	120	1	7
@@ -771,7 +775,7 @@ rm obs exp
 ###########################################################
 #  Test stdev
 ############################################################
-echo "    map.t51...\c"
+echo -e "    map.t51...\c"
 echo \
 "chr1	0	100	3.593976442
 chr1	100	200	0
@@ -786,7 +790,7 @@ rm obs exp
 ###########################################################
 #  Test sstdev
 ############################################################
-echo "    map.t52...\c"
+echo -e "    map.t52...\c"
 echo \
 "chr1	0	100	3.937003937
 chr1	100	200	.
@@ -801,7 +805,7 @@ rm obs exp
 ###########################################################
 #  Test BAM file as DB
 ############################################################
-echo "    map.t53...\c"
+echo -e "    map.t53...\c"
 echo \
 "chr1	10000	12000	2.5
 chr1	15000	20000	11.44444444" > exp
@@ -814,7 +818,7 @@ rm exp obs
 #  Bug 262: Test stranded map with BedPlus records. 
 # -s (lowercase) should give results
 ############################################################
-echo "    map.t54...\c"
+echo -e "    map.t54...\c"
 echo \
 "1	3215742	3216021	.	0	-	1
 1	3217007	3218115	.	0	-	1" > exp
@@ -827,7 +831,7 @@ rm exp obs
 #  Bug 262: Test stranded map with BedPlus records. 
 # -S (uppercase) should NOT give results
 ############################################################
-echo "    map.t55...\c"
+echo -e "    map.t55...\c"
 echo \
 "1	3215742	3216021	.	0	-	.
 1	3217007	3218115	.	0	-	." > exp
@@ -837,3 +841,4 @@ rm exp obs
 
 
 
+[[ $FAILURES -eq 0 ]] || exit 1;
